@@ -1,10 +1,30 @@
 brm_archetype_init <- function(
   data,
   interest,
-  nuisance,
   mapping,
+  intercept,
+  baseline,
+  baseline_subgroup,
+  baseline_subgroup_time,
+  baseline_time,
+  covariates,
+  prefix_nuisance,
   subclass
 ) {
+  assert_lgl(intercept, "intercept must be TRUE or FALSE")
+  if (intercept) {
+    interest[[1L]] <- 1L
+  }
+  nuisance <- archetype_nuisance(
+    data = data,
+    interest = interest,
+    prefix = prefix_nuisance,
+    covariates = covariates,
+    baseline = baseline,
+    baseline_subgroup = baseline_subgroup,
+    baseline_subgroup_time = baseline_subgroup_time,
+    baseline_time = baseline_time
+  )
   data_interest <- intersect(colnames(data), colnames(interest))
   data_nuisance <- intersect(colnames(data), colnames(nuisance))
   interest_nuisance <- intersect(colnames(interest), colnames(nuisance))
@@ -113,34 +133,37 @@ brm_data_validate.brms_mmrm_archetype <- function(data) {
     !anyDuplicated(mapping$variable),
     message = "mapping$variable must have all unique values"
   )
-  groups <- attr(data, "brm_levels_group")
-  subgroups <- attr(data, "brm_levels_subgroup")
-  times <- attr(data, "brm_levels_time")
+  groups <- brm_levels(data[[attr(data, "brm_group")]])
+  subgroups <- if_any(
+    is.null(attr(data, "brm_subgroup")),
+    character(0L),
+    brm_levels(data[[attr(data, "brm_subgroup")]])
+  )
+  times <-  brm_levels(data[[attr(data, "brm_time")]])
   n_group <- length(groups)
   n_subgroup <- length(subgroups)
   n_time <- length(times)
   if (brm_data_has_subgroup(data)) {
     assert(
-      mapping$group == rep(groups, each = n_subgroup * n_time),
-      message = "malformed or misordered mapping group levels"
+      all(mapping$group %in% groups),
+      message = "informative prior archetype mapping has bad group levels"
     )
     assert(
-      mapping$subgroup ==
-        rep(rep(subgroups, times = n_group), each = n_time),
-      message = "malformed or misordered mapping group levels"
+      all(mapping$subgroup %in% subgroups),
+      message = "informative prior archetype mapping has bad subgroup levels"
     )
     assert(
-      mapping$time == rep(times, times = n_group * n_subgroup),
-      message = "malformed or misordered mapping group levels"
+      all(mapping$time %in% times),
+      message = "informative prior archetype mapping has bad time levels"
     )
   } else {
     assert(
-      mapping$group == rep(groups, each = n_time),
-      message = "malformed or misordered mapping group levels"
+      all(mapping$group %in% groups),
+      message = "informative prior archetype mapping has bad group levels"
     )
     assert(
-      mapping$time == rep(times, times = n_group),
-      message = "malformed or misordered mapping group levels"
+      all(mapping$time %in% times),
+      message = "informative prior archetype mapping has bad time levels"
     )
   }
   NextMethod()
@@ -163,37 +186,89 @@ brm_archetype_attributes <- function(data) {
   out
 }
 
+#' @title Summarize an informative prior archetype.
 #' @export
-summary.brms_mmrm_archetype <- function(object, ...) {
+#' @keywords internal
+#' @description For an informative prior archetype, show
+#'   the transformation from model parameters to marginal means.
+#' @return Return a character vector with linear equations
+#'   that map model parameters to marginal means. If the `message`
+#'   argument is `TRUE` (default) then this character vector is returned
+#'   invisibly and a verbose description of the equations is printed.
+#' @param object The informative prior archetype to summarize.
+#' @param message TRUE to print an informative message about the archetype
+#'   and invisibly return a character vector of equations. `FALSE`
+#'   to forgo verbose messages and non-invisibly return the equations.
+#' @param ... Not used, but required for S3 methods that inherit from
+#'   the base generic [summary()].
+#' @examples
+#' data <- brm_simulate_outline(
+#'   n_group = 2,
+#'   n_patient = 100,
+#'   n_time = 4,
+#'   rate_dropout = 0,
+#'   rate_lapse = 0
+#' ) |>
+#'   dplyr::mutate(response = rnorm(n = dplyr::n())) |>
+#'   brm_data_change() |>
+#'   brm_simulate_continuous(names = c("biomarker1", "biomarker2")) |>
+#'   brm_simulate_categorical(
+#'     names = c("status1", "status2"),
+#'     levels = c("present", "absent")
+#'   )
+#' dplyr::select(
+#'   data,
+#'   group,
+#'   time,
+#'   patient,
+#'   starts_with("biomarker"),
+#'   starts_with("status")
+#' )
+#' archetype <- brm_archetype_successive_cells(data)
+#' equations <- summary(archetype)
+#' print(equations)
+#' summary(archetype, message = FALSE)
+summary.brms_mmrm_archetype <- function(object, message = TRUE, ...) {
   formula <- brm_formula(object)
-  transform <- brm_transform_marginal(object, formula, prefix = "")
-  transform <- transform[, attr(object, "brm_archetype_interest")]
-  marginals <- gsub(brm_sep(), ":", rownames(transform), fixed = TRUE)
+  transform <- brm_transform_marginal(
+    object,
+    formula,
+    average_within_subgroup = FALSE,
+    prefix = ""
+  )
   lines <- c(
     "This is the \"%s\" informative prior archetype in brms.mmrm.",
     "The following equations show the relationships between the",
     "marginal means (left-hand side) and fixed effect parameters",
-    "(right-hand side). You can create informative priors for the",
-    "fixed effect parameters using historical borrowing,",
-    "expert elicitation, or other methods.",
+    "(right-hand side).",
     ""
   )
   name <- gsub("^brms_mmrm_", "", class(object)[1L])
   name <- gsub("_", " ", name)
   lines <- sprintf(lines, name)
-  for (index in seq_along(marginals)) {
-    coef <- transform[index, ]
-    terms <- colnames(transform)[coef != 0]
-    coef <- unname(round(coef[coef != 0], digits = 2))
-    sign <- ifelse(coef < 0, "- ", "+ ")
-    sign[1L] <- ""
-    coef[seq_along(coef) > 1L] <- abs(coef[seq_along(coef) > 1L])
-    prefix <- ifelse(coef == 1, "", paste0(coef, "*"))
-    terms <- paste0(sign, prefix, terms)
-    line <- paste("  ", marginals[index], "=", paste(terms, collapse = " "))
-    lines <- c(lines, line)
+  transform <- transform[, attr(object, "brm_archetype_interest")]
+  out <- brm_transform_marginal_lines(transform)
+  lines_transform <- paste(" ", out)
+  lines <- paste("#", c(lines, lines_transform), sep = " ")
+  if (message) {
+    message(paste(lines, collapse = "\n"))
+    return(invisible(out))
+  } else {
+    out
   }
-  lines <- paste("#", lines, sep = " ")
-  cat(lines, sep = "\n")
-  invisible()
+}
+
+brm_archetype_assert_prefixes <- function(prefix_interest, prefix_nuisance) {
+  assert_chr(
+    prefix_interest %||nzchar% "x",
+    "prefix_interest must be a single character string"
+  )
+  assert_chr(
+    prefix_nuisance %||nzchar% "x",
+    "prefix_nuisance must be a single character string"
+  )
+  assert(
+    prefix_interest != prefix_nuisance,
+    message = "prefix_interest and prefix_nuisance must be different"
+  )
 }
